@@ -9,22 +9,24 @@ from .healthcheck import HealthCheck
 from .email import Email
 from .mongo import Mongo
 from .pdf import Pdf
-from .plot import Plot
+from .plotly import Plotly
 from .html import Html
 from .cityfalcon import Cityfalcon
 from .prediction import Prediction
 from .sentiment_analysis import SentimentAnalysis
 from .toucan import Toucan
+from .yahoo import Yahoo
 from airtable import Airtable
 from .zappier import Zappier
 from .ifttt import Ifttt
 
-__version__ = "0.13.1"
+__version__ = "0.14.0"
 
 darkknight = DarkKnight
 airtable = Airtable
 zappier = Zappier
 ifttt = Ifttt
+yahoo = Yahoo
 ftp = Ftp
 ftps = Ftps
 ftps_toucan = Ftps_toucan
@@ -35,7 +37,7 @@ health_check = HealthCheck
 email = Email
 mongo = Mongo
 pdf = Pdf
-plot = Plot
+plotly = Plotly
 html = Html
 cityfalcon = Cityfalcon
 prediction = Prediction
